==> zio-aws-iotsitewise_2.12-5.17.112.1-sources.jar: zio/aws/iotsitewise/model/ListDashboardsResponse.scala <==
package zio.aws.iotsitewise.model
import zio.ZIO
import zio.aws.iotsitewise.model.primitives.NextToken
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListDashboardsResponse(
    dashboardSummaries: Iterable[zio.aws.iotsitewise.model.DashboardSummary],
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotsitewise.model.ListDashboardsResponse = {
    import ListDashboardsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotsitewise.model.ListDashboardsResponse
      .builder()
      .dashboardSummaries(dashboardSummaries.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.iotsitewise.model.ListDashboardsResponse.ReadOnly =
    zio.aws.iotsitewise.model.ListDashboardsResponse.wrap(buildAwsValue())
}
object ListDashboardsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotsitewise.model.ListDashboardsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotsitewise.model.ListDashboardsResponse =
      zio.aws.iotsitewise.model.ListDashboardsResponse(
        dashboardSummaries.map { item =>
          item.asEditable
        },
        nextToken.map(value => value)
      )
    def dashboardSummaries
        : List[zio.aws.iotsitewise.model.DashboardSummary.ReadOnly]
    def nextToken: Option[NextToken]
    def getDashboardSummaries: ZIO[Any, Nothing, List[
      zio.aws.iotsitewise.model.DashboardSummary.ReadOnly
    ]] = ZIO.succeed(dashboardSummaries)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotsitewise.model.ListDashboardsResponse
  ) extends zio.aws.iotsitewise.model.ListDashboardsResponse.ReadOnly {
    override val dashboardSummaries
        : List[zio.aws.iotsitewise.model.DashboardSummary.ReadOnly] = impl
      .dashboardSummaries()
      .asScala
      .map { item =>
        zio.aws.iotsitewise.model.DashboardSummary.wrap(item)
      }
      .toList
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.iotsitewise.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotsitewise.model.ListDashboardsResponse
  ): zio.aws.iotsitewise.model.ListDashboardsResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-iotsitewise_2.12-6.20.56.2-sources.jar: zio/aws/iotsitewise/model/ListDashboardsResponse.scala <==
package zio.aws.iotsitewise.model
import zio.ZIO
import zio.aws.iotsitewise.model.primitives.NextToken
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListDashboardsResponse(
    dashboardSummaries: Iterable[zio.aws.iotsitewise.model.DashboardSummary],
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotsitewise.model.ListDashboardsResponse = {
    import ListDashboardsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotsitewise.model.ListDashboardsResponse
      .builder()
      .dashboardSummaries(dashboardSummaries.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.iotsitewise.model.ListDashboardsResponse.ReadOnly =
    zio.aws.iotsitewise.model.ListDashboardsResponse.wrap(buildAwsValue())
}
object ListDashboardsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotsitewise.model.ListDashboardsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotsitewise.model.ListDashboardsResponse =
      zio.aws.iotsitewise.model.ListDashboardsResponse(
        dashboardSummaries.map { item =>
          item.asEditable
        },
        nextToken.map(value => value)
      )
    def dashboardSummaries
        : List[zio.aws.iotsitewise.model.DashboardSummary.ReadOnly]
    def nextToken: Optional[NextToken]
    def getDashboardSummaries: ZIO[Any, Nothing, List[
      zio.aws.iotsitewise.model.DashboardSummary.ReadOnly
    ]] = ZIO.succeed(dashboardSummaries)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotsitewise.model.ListDashboardsResponse
  ) extends zio.aws.iotsitewise.model.ListDashboardsResponse.ReadOnly {
    override val dashboardSummaries
        : List[zio.aws.iotsitewise.model.DashboardSummary.ReadOnly] = impl
      .dashboardSummaries()
      .asScala
      .map { item =>
        zio.aws.iotsitewise.model.DashboardSummary.wrap(item)
      }
      .toList
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.iotsitewise.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotsitewise.model.ListDashboardsResponse
  ): zio.aws.iotsitewise.model.ListDashboardsResponse.ReadOnly = new Wrapper(
    impl
  )
}
